trimestreAnoExt method
Retorna trimestre e ano por extenso no formato [trimestre]º trimestre de [ano].
Ex: 2º trimestre de 1987
Implementation
String trimestreAnoExt() {
initializeDateFormatting();
return DateFormat.yQQQQ(br).format(this);
}
Retorna trimestre e ano por extenso no formato [trimestre]º trimestre de [ano].
Ex: 2º trimestre de 1987
String trimestreAnoExt() {
initializeDateFormatting();
return DateFormat.yQQQQ(br).format(this);
}